# Guide

Manage notebooks interactively:

- {doc}`../quickstart`
- {doc}`received`
- {doc}`basic-metadata`
- {doc}`update-metadata`

Manage a collection of notebooks:

- {doc}`cli`

Build on the metadata API:

- {doc}`meta`

```{toctree}
:maxdepth: 1
:hidden:

../quickstart
received
basic-metadata
update-metadata
cli
meta
```
